************************************************
** ADRIAN SHIN          				 *******
** Exchange Rates and Immigration Policy *******
** February, 2021     					 *******
************************************************
*Full title: "Exchange Rates and Immigration Policy"     
*This material is based upon work supported by the National Science Foundation Graduate Student Research Fellowship under Grant No. DGE 0718128.
clear
cd "/Users/Adrian/Box Sync/Colorado/Jounal Submissions/Comparative Migration Studies/Final Files/Test Run/"
use "mrer_total_collapsed.dta"
gen sample = 0
replace sample = 1 if dest_ccode==2 //US
replace sample = 1 if dest_ccode==20 //Canada
replace sample = 1 if dest_ccode==305 // Austria
replace sample = 1 if dest_ccode==211 // Belgium
replace sample = 1 if dest_ccode==390 // Denmark
replace sample = 1 if dest_ccode==220 // France
replace sample = 1 if dest_ccode==255 // Germany
replace sample = 1 if dest_ccode==210 // Netherlands
replace sample = 1 if dest_ccode==385 // Norway
replace sample = 1 if dest_ccode==380 // Sweden
replace sample = 1 if dest_ccode==225 // Switzerland
replace sample = 1 if dest_ccode==200 // UK

gen country=""
replace country="United States" if dest_ccode==2
replace country="Canada" if dest_ccode==20
replace country="Austria" if dest_ccode==305
replace country="Belgium" if dest_ccode==211
replace country="Denmark" if dest_ccode==390
replace country="France" if dest_ccode==220
replace country="Germany" if dest_ccode==255
replace country="Netherlands" if dest_ccode==210
replace country="Norway" if dest_ccode==385
replace country="Sweden" if dest_ccode==380
replace country="Switzerland" if dest_ccode==225
replace country="United Kingdom" if dest_ccode==200

*Figure 1: MRER Trends in High-Income Immigrant Destinations
twoway (area ex_ji_total year, fcolor(%50) lcolor(%50)) if sample==1, ytitle(Migrant-Weighted Real Exchange Rate (MRER)) ytitle(, size(medium)) xtitle(Year) xtitle(, size(medium)) ylabel(,nogrid) xscale(noline) by(, legend(off)) by(, graphregion(fcolor(white))) by(country)

clear
use "CMS Replication.dta"
*Table 1: Individual Equality Dimension (1980-2008)
gen t = .
replace t = 1 if year==1980
replace t = 2 if year==1990
replace t = 3 if year==2002
replace t = 4 if year==2008
xtset ccode t
xtpcse individual_equality_dim ex_ji_total year_1990 year_2002 year_2008
estimates store MODEL1, title((1))
xtpcse individual_equality_dim ex_ji_total gdp_per_capita_1000 year_1990 year_2002 year_2008
estimates store MODEL2, title((2))
xtpcse individual_equality_dim ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODEL3, title((3))
xtpcse individual_equality_dim l.individual_equality_dim ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODEL4, title((4))
xtpcse individual_equality_dim ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008 i.ccode
estimates store MODEL5, title((5))
estout MODEL1 MODEL2 MODEL3 MODEL4 MODEL5, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using model12345.tex, replace style(tex)

*Table 2: Individual Equality Dimension Robustness Checks (1980-2008)
xtpcse individual_equality_dim ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE polity2_total gdp_pc_1000 gdp_growth reer immipol ln_population migrant_share year_1990 year_2002 year_2008 i.ccode
estimates store MODEL6, title((6))
xtpcse individual_equality_dim ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE heg_d_total lp1_total year_1990 year_2002 year_2008 i.ccode 
estimates store MODEL7, title((7))
xtpcse individual_equality_dim ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE polity2_total gdp_pc_1000 gdp_growth reer immipol ln_population migrant_share heg_d_total lp1_total year_1990 year_2002 year_2008 i.ccode
estimates store MODEL8, title((8))
estout MODEL6 MODEL7 MODEL8, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using model678.tex, replace style(tex)

*Table 3: Immigrant Rights - Alternative Dependent Measures
clear
use "Peters and Shin.dta"
xtpcse rightscode ex_ji_total gdp_per_capita_total_1000 rwpvote ud i.year
estimates store MODEL9, title((9))
use "IMPIC.dta"
recode S_f01 (0=1) (1=0)
xtpcse S_f01 ex_ji_total gdp_per_capita_total_1000  rwpvote  ud i.year 
estimates store MODEL10, title((10))
oprobit S_f01 ex_ji_total gdp_per_capita_total_1000 rwpvote ud i.year, cluster(dest_ccode)
estimates store MODEL11, title((11))
estout MODEL9 MODEL10 MODEL11, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using model91011.tex, replace style(tex)

***Appendix
*Table A1: Summary Statistics
clear
use "CMS Replication.dta"
ssc install sutex
sutex  nationality_acquisition expulsion marriage_migration anti_discrimination political_rights individual_equality_dim culture_religion culture_dim reer ex_ji_total lp1_total heg_d_total immigrant_vote RWPVOTE trade_union polity2_total gdp_per_capita_1000 gdp_per_capita_ne_1000 ln_population migrant_share immipol gdp_pc_1000, minmax lab

*Table A2: Indicators of Immigrant Rights by Policy Field and Theoretical Dimension

*Table A3: Emigration and Exchange Rate Movements
clear
use "EMIG Data.dta"
reg ln_emig reer_delta i.ccode i.year, cluster(ccode)
estimates store MODELa1, title((a1))
reg ln_emig reer_delta lngdppc gdpgrowth ln_pop i.ccode i.year, cluster(ccode)
estimates store MODELa2, title((a2))
estout MODELa1 MODELa2, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela12.tex, replace style(tex)

*Table A4: Nationality Acquisition (1980-2008)
clear
use "CMS Replication.dta"
gen t = .
replace t = 1 if year==1980
replace t = 2 if year==1990
replace t = 3 if year==2002
replace t = 4 if year==2008
xtset ccode t
xtpcse nationality_acquisition ex_ji_total year_1990 year_2002 year_2008
estimates store MODELa3, title((a3))
xtpcse nationality_acquisition ex_ji_total gdp_per_capita_1000 year_1990 year_2002 year_2008
estimates store MODELa4, title((a4))
xtpcse nationality_acquisition ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa5, title((a5))
xtpcse nationality_acquisition l.nationality_acquisition ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa6, title((a6))
xtpcse nationality_acquisition ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008 i.ccode
estimates store MODELa7, title((a7))
estout MODELa3 MODELa4 MODELa5 MODELa6 MODELa7, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela3_7.tex, replace style(tex)

*Table A5: Expulsion (1980-2008)
xtpcse expulsion ex_ji_total year_1990 year_2002 year_2008
estimates store MODELa8, title((a8))
xtpcse expulsion ex_ji_total gdp_per_capita_1000 year_1990 year_2002 year_2008
estimates store MODELa9, title((a9))
xtpcse expulsion ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa10, title((a10))
xtpcse expulsion l.expulsion ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa11, title((a11))
xtpcse expulsion ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008 i.ccode
estimates store MODELa12, title((a12))
estout MODELa8 MODELa9 MODELa10 MODELa11 MODELa12, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela8_12.tex, replace style(tex)

*Table A6: Anti-Discrimination (1980-2008)
xtpcse anti_discrimination ex_ji_total year_1990 year_2002 year_2008
estimates store MODELa13, title((a13))
xtpcse anti_discrimination ex_ji_total gdp_per_capita_1000 year_1990 year_2002 year_2008
estimates store MODELa14, title((a14))
xtpcse anti_discrimination ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa15, title((a15))
xtpcse anti_discrimination l.anti_discrimination ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa16, title((a16))
xtpcse anti_discrimination ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008 i.ccode
estimates store MODELa17, title((a17))
estout MODELa13 MODELa14 MODELa15 MODELa16 MODELa17, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela13_17.tex, replace style(tex)

*Table A7: Political Rights (1980-2008)
xtpcse political_rights ex_ji_total year_1990 year_2002 year_2008
estimates store MODELa18, title((a18))
xtpcse political_rights ex_ji_total gdp_per_capita_1000 year_1990 year_2002 year_2008
estimates store MODELa19, title((a19))
xtpcse political_rights ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa20, title((a20))
xtpcse political_rights l.political_rights ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa21, title((a21))
xtpcse political_rights ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008 i.ccode
estimates store MODELa22, title((a22))
estout MODELa18 MODELa19 MODELa20 MODELa21 MODELa22, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela18_22.tex, replace style(tex)

*Table A8: Marriage Migration (1980-2008)
xtpcse marriage_migration ex_ji_total year_1990 year_2002 year_2008
estimates store MODELa23, title((a23))
xtpcse marriage_migration ex_ji_total gdp_per_capita_1000 year_1990 year_2002 year_2008
estimates store MODELa24, title((a24))
xtpcse marriage_migration ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa25, title((a25))
xtpcse marriage_migration l.marriage_migration ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa26, title((a26))
xtpcse marriage_migration ex_ji_total gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008 i.ccode
estimates store MODELa27, title((a27))
estout MODELa23 MODELa24 MODELa25 MODELa26 MODELa27, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela23_27.tex, replace style(tex)

*Table A9: Cultural Dimension (1980-2008)
xtpcse culture_dim ex_ji_non_eea year_1990 year_2002 year_2008
estimates store MODELa28, title((a28))
xtpcse culture_dim ex_ji_non_eea gdp_per_capita_ne_1000 year_1990 year_2002 year_2008
estimates store MODELa29, title((a29))
xtpcse culture_dim ex_ji_non_eea gdp_per_capita_ne_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa30, title((a30))
xtpcse culture_dim l.culture_dim ex_ji_non_eea gdp_per_capita_ne_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa31, title((a31))
xtpcse culture_dim ex_ji_non_eea gdp_per_capita_ne_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008 i.ccode
estimates store MODELa32, title((a32))
estout MODELa28 MODELa29 MODELa30 MODELa31 MODELa32, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela28_32.tex, replace style(tex)

*Table A10: Cultural and Religious Rights (1980-2008)
xtpcse culture_religion ex_ji_non_eea year_1990 year_2002 year_2008
estimates store MODELa33, title((a33))
xtpcse culture_religion ex_ji_non_eea gdp_per_capita_ne_1000 year_1990 year_2002 year_2008
estimates store MODELa34, title((a34))
xtpcse culture_religion ex_ji_non_eea gdp_per_capita_ne_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa35, title((a35))
xtpcse culture_religion l.culture_religion ex_ji_non_eea gdp_per_capita_ne_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa36, title((a36))
xtpcse culture_religion ex_ji_non_eea gdp_per_capita_ne_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008 i.ccode
estimates store MODELa37, title((a37))
estout MODELa33 MODELa34 MODELa35 MODELa36 MODELa37, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela33_37.tex, replace style(tex)

*Table A11: Individual Equality Dimension and Currency Volatility (1990-2008)
*Merged in Coefficient of Variation and controlled for it. Results are robust and some evidence to suggest greater CV leads to more rights
gen countryyear = ccode*10000+year
merge 1:1 countryyear using "MRER_cv.dta"
drop _merge
drop dest_ccode
xtset ccode t
xtpcse individual_equality_dim ex_ji_total MRER_cv  year_2002 year_2008
estimates store MODELa38, title((A38))
xtpcse individual_equality_dim ex_ji_total MRER_cv gdp_per_capita_1000  year_2002 year_2008
estimates store MODELa39, title((A39))
xtpcse individual_equality_dim ex_ji_total MRER_cv gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE  year_2002 year_2008
estimates store MODELa40, title((A40))
xtpcse individual_equality_dim l.individual_equality_dim ex_ji_total MRER_cv gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE year_1990 year_2002 year_2008
estimates store MODELa41, title((A41))
xtpcse individual_equality_dim ex_ji_total MRER_cv gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE  year_2002 year_2008 i.ccode
estimates store MODELa42, title((A42))
estout MODELa38 MODELa39 MODELa40 MODELa41 MODELa42, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela38_42.tex, replace style(tex)


*Generated variable that denotes CHANGE in MRER
by ccode: gen ex_ji_change = ex_ji_total-l.ex_ji_total
by ccode: gen ex_ji_change_per = ((ex_ji_total-l.ex_ji_total)/l.ex_ji_total)*100

*Table A12: Effect of MRER Changes on Individual Equality Dimension (1990-2008)
xtpcse individual_equality_dim ex_ji_change i.year
estimates store MODELa43, title((A43))
xtpcse individual_equality_dim ex_ji_change gdp_per_capita_1000 i.year
estimates store MODELa44, title((A44))
xtpcse individual_equality_dim ex_ji_change gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE i.year
estimates store MODELa45, title((A45))
xtpcse individual_equality_dim ex_ji_change gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE i.year i.ccode
estimates store MODELa46, title((A46))
estout MODELa43 MODELa44 MODELa45 MODELa46, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela43_46.tex, replace style(tex)


*Table A13: Effect of MRER Changes (%) on Individual Equality Dimension (1990-2008)
xtpcse individual_equality_dim ex_ji_change_per i.year
estimates store MODELa47, title((A47))
xtpcse individual_equality_dim ex_ji_change_per gdp_per_capita_1000 i.year
estimates store MODELa48, title((A48))
xtpcse individual_equality_dim ex_ji_change_per gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE i.year
estimates store MODELa49, title((A49))
xtpcse individual_equality_dim ex_ji_change_per gdp_per_capita_1000 immigrant_vote trade_union RWPVOTE i.year i.ccode
estimates store MODELa50, title((A50))
estout MODELa47 MODELa48 MODELa49 MODELa50, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R2)) label , using modela47_50.tex, replace style(tex)

